@@ -32,7 +32,7 @@ char copyright[] =
  All rights reserved.\n";
 #endif /* not lint */
 
-/* $Header: /home/daffy/u0/vern/flex/RCS/main.c,v 2.35 93/12/07 10:18:26 vern Exp $ */
+/* $Header: /home/daffy/u0/vern/flex/RCS/main.c,v 2.37 93/12/11 10:29:39 vern Exp $ */
 
 
 #include "flexdef.h"
@@ -119,64 +119,6 @@ char **argv;
 
 	readin();
 
-	if ( syntaxerror )
-		flexend( 1 );
-
-	if ( yymore_really_used == REALLY_USED )
-		yymore_used = true;
-	else if ( yymore_really_used == REALLY_NOT_USED )
-		yymore_used = false;
-
-	if ( reject_really_used == REALLY_USED )
-		reject = true;
-	else if ( reject_really_used == REALLY_NOT_USED )
-		reject = false;
-
-	if ( performance_report > 0 )
-		{
-		if ( lex_compat )
-			{
-			fprintf( stderr,
-"-l AT&T lex compatibility option entails a large performance penalty\n" );
-			fprintf( stderr,
-" and may be the actual source of other reported performance penalties\n" );
-			}
-
-		if ( performance_report > 1 )
-			{
-			if ( interactive )
-				fprintf( stderr,
-		"-I (interactive) entails a minor performance penalty\n" );
-
-			if ( yymore_used )
-				fprintf( stderr,
-			"yymore() entails a minor performance penalty\n" );
-			}
-
-		if ( reject )
-			fprintf( stderr,
-			"REJECT entails a large performance penalty\n" );
-
-		if ( variable_trailing_context_rules )
-			fprintf( stderr,
-"Variable trailing context rules entail a large performance penalty\n" );
-		}
-
-	if ( reject )
-		real_reject = true;
-
-	if ( variable_trailing_context_rules )
-		reject = true;
-
-	if ( (fulltbl || fullspd) && reject )
-		{
-		if ( real_reject )
-			flexerror( "REJECT cannot be used with -f or -F" );
-		else
-			flexerror(
-	"variable trailing context rules cannot be used with -f or -F" );
-		}
-
 	ntod();
 
 	for ( i = 1; i <= num_rules; ++i )
@@ -817,6 +759,64 @@ void readin()
 		flexend( 1 );
 		}
 
+	if ( syntaxerror )
+		flexend( 1 );
+
+	if ( yymore_really_used == REALLY_USED )
+		yymore_used = true;
+	else if ( yymore_really_used == REALLY_NOT_USED )
+		yymore_used = false;
+
+	if ( reject_really_used == REALLY_USED )
+		reject = true;
+	else if ( reject_really_used == REALLY_NOT_USED )
+		reject = false;
+
+	if ( performance_report > 0 )
+		{
+		if ( lex_compat )
+			{
+			fprintf( stderr,
+"-l AT&T lex compatibility option entails a large performance penalty\n" );
+			fprintf( stderr,
+" and may be the actual source of other reported performance penalties\n" );
+			}
+
+		if ( performance_report > 1 )
+			{
+			if ( interactive )
+				fprintf( stderr,
+		"-I (interactive) entails a minor performance penalty\n" );
+
+			if ( yymore_used )
+				fprintf( stderr,
+			"yymore() entails a minor performance penalty\n" );
+			}
+
+		if ( reject )
+			fprintf( stderr,
+			"REJECT entails a large performance penalty\n" );
+
+		if ( variable_trailing_context_rules )
+			fprintf( stderr,
+"Variable trailing context rules entail a large performance penalty\n" );
+		}
+
+	if ( reject )
+		real_reject = true;
+
+	if ( variable_trailing_context_rules )
+		reject = true;
+
+	if ( (fulltbl || fullspd) && reject )
+		{
+		if ( real_reject )
+			flexerror( "REJECT cannot be used with -f or -F" );
+		else
+			flexerror(
+	"variable trailing context rules cannot be used with -f or -F" );
+		}
+
 	if ( csize == 256 )
 		puts( "typedef unsigned char YY_CHAR;" );
 	else
@@ -852,7 +852,7 @@ void readin()
 		printf( "FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;\n" );
 
 	if ( C_plus_plus )
-		printf( "\n#include \"FlexLexer.h\"\n" );
+		printf( "\n#include <FlexLexer.h>\n" );
 
 	else
 		{
